==> jc-1.4.0.tar.gz: soot/coffi/method__5finfo.h <==
// public class soot.coffi.method_info

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 76eac3ae06fd85f6 soot_coffi_method__5finfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_method__5finfo_H_
#define _JC_soot_coffi_method__5finfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_coffi_CFG$object;
struct _jc_soot_coffi_Code__5fattribute$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_method__5finfo$sub_refs	_jc_soot_coffi_method__5finfo$sub_refs;
typedef struct _jc_soot_coffi_method__5finfo$sub_nonrefs	_jc_soot_coffi_method__5finfo$sub_nonrefs;
typedef struct _jc_soot_coffi_method__5finfo$refs	_jc_soot_coffi_method__5finfo$refs;
typedef struct _jc_soot_coffi_method__5finfo$nonrefs	_jc_soot_coffi_method__5finfo$nonrefs;
typedef struct _jc_soot_coffi_method__5finfo$object	_jc_soot_coffi_method__5finfo$object;

typedef const struct _jc_soot_coffi_method__5finfo$vmethods	_jc_soot_coffi_method__5finfo$vmethods;
typedef const struct _jc_soot_coffi_method__5finfo$vtable	_jc_soot_coffi_method__5finfo$vtable;
typedef const struct _jc_soot_coffi_method__5finfo$vtype	_jc_soot_coffi_method__5finfo$vtype;

// Constructors
extern void _jc_soot_coffi_method__5finfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *);

// Virtual methods
extern struct _jc_soot_coffi_Code__5fattribute$object *_jc_soot_coffi_method__5finfo$method$locate__5fcode__5fattribute$c048d30cc3fb4389(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *);
extern void _jc_soot_coffi_method__5finfo$method$print$9fef0c13ef5390e4(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_method__5finfo$method$prototype$fc9bbd112c759615(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_method__5finfo$method$toName$f6140eb5ad286203(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_method__5finfo$method_info$locate__5fcode__5fattribute$c048d30cc3fb4389;
extern _jc_method _jc_soot_coffi_method__5finfo$method_info$print$9fef0c13ef5390e4;
extern _jc_method _jc_soot_coffi_method__5finfo$method_info$prototype$fc9bbd112c759615;
extern _jc_method _jc_soot_coffi_method__5finfo$method_info$toName$f6140eb5ad286203;

// Virtual methods structure
struct _jc_soot_coffi_method__5finfo$vmethods {
	struct _jc_soot_coffi_Code__5fattribute$object	*(*locate__5fcode__5fattribute$c048d30cc3fb4389)(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *);
	void	(*print$9fef0c13ef5390e4)(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *);
	struct _jc_java_lang_String$object	*(*prototype$fc9bbd112c759615)(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *);
	struct _jc_java_lang_String$object	*(*toName$f6140eb5ad286203)(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_method__5finfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_method__5finfo$vmethods	soot_coffi_method__5finfo;
};

// Vtype
struct _jc_soot_coffi_method__5finfo$vtype {
	_jc_type			type;
	_jc_soot_coffi_method__5finfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_method__5finfo$sub_refs {
	_jc_object_array	*attributes;
	struct _jc_soot_coffi_Code__5fattribute$object	*code__5fattr;
	struct _jc_soot_coffi_Instruction$object	*instructions;
	struct _jc_soot_coffi_CFG$object	*cfg;
	struct _jc_soot_SootMethod$object	*jmethod;
	struct _jc_object	*instructionList;
};

// Reference instance fields (object)
struct _jc_soot_coffi_method__5finfo$refs {
    _jc_soot_coffi_method__5finfo$sub_refs	soot_coffi_method__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_method__5finfo$sub_nonrefs {
	jint	access__5fflags;
	jint	name__5findex;
	jint	descriptor__5findex;
	jint	attributes__5fcount;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_method__5finfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_method__5finfo$sub_nonrefs	soot_coffi_method__5finfo;
};

// Object instance structure
struct _jc_soot_coffi_method__5finfo$object {
	_jc_soot_coffi_method__5finfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_method__5finfo$vtype	*vtype;
	_jc_soot_coffi_method__5finfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_method__5finfo$vtype _jc_soot_coffi_method__5finfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_method__5finfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_method__5finfo$class_object;

#endif	/* _JC_soot_coffi_method__5finfo_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/method__5finfo.h <==
// public class soot.coffi.method_info

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 76eac3ae06fd85f6 soot_coffi_method__5finfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_method__5finfo_H_
#define _JC_soot_coffi_method__5finfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_coffi_CFG$object;
struct _jc_soot_coffi_Code__5fattribute$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_method__5finfo$sub_refs	_jc_soot_coffi_method__5finfo$sub_refs;
typedef struct _jc_soot_coffi_method__5finfo$sub_nonrefs	_jc_soot_coffi_method__5finfo$sub_nonrefs;
typedef struct _jc_soot_coffi_method__5finfo$refs	_jc_soot_coffi_method__5finfo$refs;
typedef struct _jc_soot_coffi_method__5finfo$nonrefs	_jc_soot_coffi_method__5finfo$nonrefs;
typedef struct _jc_soot_coffi_method__5finfo$object	_jc_soot_coffi_method__5finfo$object;

typedef const struct _jc_soot_coffi_method__5finfo$vmethods	_jc_soot_coffi_method__5finfo$vmethods;
typedef const struct _jc_soot_coffi_method__5finfo$vtable	_jc_soot_coffi_method__5finfo$vtable;
typedef const struct _jc_soot_coffi_method__5finfo$vtype	_jc_soot_coffi_method__5finfo$vtype;

// Constructors
extern void _jc_soot_coffi_method__5finfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_coffi_Code__5fattribute$object *_jc_soot_coffi_method__5finfo$method$locate__5fcode__5fattribute$c048d30cc3fb4389(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_method__5finfo$method$print$9fef0c13ef5390e4(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_method__5finfo$method$prototype$fc9bbd112c759615(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_method__5finfo$method$toName$f6140eb5ad286203(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_method__5finfo$method_info$locate__5fcode__5fattribute$c048d30cc3fb4389;
extern _jc_method _jc_soot_coffi_method__5finfo$method_info$print$9fef0c13ef5390e4;
extern _jc_method _jc_soot_coffi_method__5finfo$method_info$prototype$fc9bbd112c759615;
extern _jc_method _jc_soot_coffi_method__5finfo$method_info$toName$f6140eb5ad286203;

// Virtual methods structure
struct _jc_soot_coffi_method__5finfo$vmethods {
	struct _jc_soot_coffi_Code__5fattribute$object	*(*locate__5fcode__5fattribute$c048d30cc3fb4389)(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *) _JC_JCNI_ATTR;
	void	(*print$9fef0c13ef5390e4)(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*prototype$fc9bbd112c759615)(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toName$f6140eb5ad286203)(_jc_env *, struct _jc_soot_coffi_method__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_method__5finfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_method__5finfo$vmethods	soot_coffi_method__5finfo;
};

// Vtype
struct _jc_soot_coffi_method__5finfo$vtype {
	_jc_type			type;
	_jc_soot_coffi_method__5finfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_method__5finfo$sub_refs {
	_jc_object_array	*attributes;
	struct _jc_soot_coffi_Code__5fattribute$object	*code__5fattr;
	struct _jc_soot_coffi_Instruction$object	*instructions;
	struct _jc_soot_coffi_CFG$object	*cfg;
	struct _jc_soot_SootMethod$object	*jmethod;
	struct _jc_object	*instructionList;
};

// Reference instance fields (object)
struct _jc_soot_coffi_method__5finfo$refs {
    _jc_soot_coffi_method__5finfo$sub_refs	soot_coffi_method__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_method__5finfo$sub_nonrefs {
	jint	access__5fflags;
	jint	name__5findex;
	jint	descriptor__5findex;
	jint	attributes__5fcount;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_method__5finfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_method__5finfo$sub_nonrefs	soot_coffi_method__5finfo;
};

// Object instance structure
struct _jc_soot_coffi_method__5finfo$object {
	_jc_soot_coffi_method__5finfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_method__5finfo$vtype	*vtype;
	_jc_soot_coffi_method__5finfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_method__5finfo$vtype _jc_soot_coffi_method__5finfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_method__5finfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_method__5finfo$class_object;

#endif	/* _JC_soot_coffi_method__5finfo_H_ */
